#
# spec file for package aravis
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define url_ver %(echo %{version}|cut -d. -f1,2)
%define api   0.8
%define sover 0
%define sorel %(echo %{api} | tr . _)
%define libname lib%{name}-%{sorel}-%{sover}
%define devname lib%{name}-%{sorel}-devel
%define typelibname typelib-1_0-Aravis-%{api}
Name:           aravis
Version:        0.8.33
Release:        1.3
Summary:        Glib/gobject based library implementing a Genicam interface
License:        LGPL-2.1-or-later
Group:          Productivity/Multimedia/Video/Players
URL:            https://github.com/AravisProject/aravis
Source:         https://github.com/AravisProject/%{name}/releases/download/%{version}/aravis-%{version}.tar.xz
BuildRequires:  %{python_module gobject}
BuildRequires:  gcc-c++
BuildRequires:  gobject-introspection
BuildRequires:  gtk-doc
BuildRequires:  intltool
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gi-docgen) >= 2021.1
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-app-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(libxml-2.0)

%description
Aravis is a glib/gobject based library implementing a Genicam interface,
which can be used for the acquisition of video streams coming from either
ethernet, firewire or USB cameras. It currently only implements an ethernet
camera protocol used for industrial cameras.

%package viewer
Summary:        Glib/gobject based library implementing a Genicam interface
Group:          Productivity/Multimedia/Video/Players
Recommends:     gstreamer-plugins-bad
Recommends:     gstreamer-plugins-base
Recommends:     gstreamer-plugins-good

%description viewer
This package contains arv-viewer, GUI application for aravis.

%package -n %{libname}
Summary:        Shared library for %{name}
Group:          System/Libraries

%description -n %{libname}
Aravis is a glib/gobject based library implementing a Genicam interface,
which can be used for the acquisition of video streams coming from either
ethernet, firewire or USB cameras. It currently only implements an ethernet
camera protocol used for industrial cameras.

This package contains the shared library for %{name}.

%package -n %{typelibname}
Summary:        Introspection bindings for %{name}
Group:          System/Libraries

%description -n %{typelibname}
This package provides the GObject Introspection bindings for %{name}.

%package -n gstreamer-plugin-%{name}
Summary:        Gstreamer support for %{name}
Group:          Productivity/Multimedia/Other

%description -n gstreamer-plugin-%{name}
This package contains the gstreamer plugin for %{name}.

%package -n %{devname}
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description -n %{devname}
This package contains the development files for %{name}

%prep
%setup -q

%build
%meson -Ddocumentation=enabled
%meson_build

%install
%meson_install

%suse_update_desktop_file -r org.aravis.viewer-%{api} AudioVideo AudioVideoEditing

%find_lang %{name}-%{api}

%check
%meson_test

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%{_bindir}/arv-camera-test-%{api}
%{_bindir}/arv-fake-gv-camera-%{api}
%{_bindir}/arv-test-%{api}
%{_bindir}/arv-tool-%{api}
%{_mandir}/man1/arv-tool-*
%{_mandir}/man1/arv-camera-test-*
%{_mandir}/man1/arv-test-*

%files viewer -f %{name}-%{api}.lang
%{_bindir}/arv-viewer-%{api}
%{_mandir}/man1/arv-viewer-*
%{_datadir}/icons/hicolor/*/apps/aravis*
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/org.aravis.viewer-%{api}.metainfo.xml
%{_datadir}/applications/org.aravis.viewer-%{api}.desktop

%files -n %{libname}
%license COPYING
%doc AUTHORS README.md NEWS.md
%{_libdir}/libaravis-%{api}.so.*

%files -n %{typelibname}
%{_libdir}/girepository-1.0/Aravis-%{api}.typelib

%files -n gstreamer-plugin-%{name}
%{_libdir}/gstreamer-1.0/libgstaravis.%{api}.so
%exclude %{_libdir}/gstreamer-1.0/libgstaravis.%{api}.la

%files -n %{devname}
%{_includedir}/%{name}-%{api}
%{_libdir}/*.so
%{_libdir}/pkgconfig/*
%{_datadir}/doc/%{name}-%{api}
%{_datadir}/gir-1.0/Aravis-%{api}.gir

%changelog
* Sat Sep  7 2024 Matwey Kornilov <matwey.kornilov@gmail.com>
- Update to 0.8.33:
  * viewer: ignore exposure time feature representation
- Update to 0.8.32:
  * viewer: workaround for Blackfly Mono16 pixel endianness issue
  * gst: disconnect camera in stop method
  * gst: stream object accessor
  * gst: camera change signal
  * gst: stream change signal
  * gst: allow software trigger
  * gvsp: fix chunk detection
  * gv_device: crach fix on finalization
  * Fix device_write_memory rust binding
  * introspection: add generic feature value accessors
  * chore: fix libxml2 deprecation warnings
  * chore: appstream fixes
* Wed Mar 13 2024 Matwey Kornilov <matwey.kornilov@gmail.com>
- Update to 0.8.31:
  * viewer: better handling of exposure and gain setting
  * genicam: genicam URL stored as DomDocument URL property
  * genicam: fix arv_device_get_feature_access_mode return value
  * camera: set/dup_register helper
  * camera: frame_rate setting improvements
  * usb3vision: handle GenDC payload
  * gigevision: set a lower boundary to minimum socket size in auto mode
  * build: fix a libxml2 API breakage
* Tue Dec 26 2023 Matwey Kornilov <matwey.kornilov@gmail.com>
- Update to 0.8.30:
  * gv: add EVK Helios and Automation Technology C6 devices to the
    legacy mode list
  * gv: don't ignore POINTTOPOINT interfaces, allows for direct
    connection to devices through VPNs
- Changes for 0.8.29:
  * usb3vision: fix callbacks triggering in async mode
  * usb3vision: fix underrun counting
- Changes for 0.8.28:
  * usb3vision: make async libusb default
  * usb3vision: improve CPU use when no buffer is available for the
    stream thread
  * usb3vision: don't wait forever for USB transfer completion
  * usb3vision: enable stream after the receiving stream thread is
    started
  * viewer: avoid buffer exhaustion if GStreamer pipeline is late
  * build: fix clang 32 bits compilation
* Mon Jul 24 2023 Matwey Kornilov <matwey.kornilov@gmail.com>
- Update to 0.8.27:
  * camera: add vendor specific quirks to frame rate
  * camera: multiple tap helpers
  * gv: start packet timeout after the first non leader packet
  * gv: auto packet size fix
  * gv: add more camera to the legacy endianness mechanism exception list
  * u3v: fix u3vcp_capability register size
  * chore: compilation warning fixes
  * ci: pipeline babysitting
  * doc: link fix
* Mon Mar 27 2023 Matwey Kornilov <matwey.kornilov@gmail.com>
- Update to 0.8.26:
  * viewer: fix pixel format selection #765
- Changes for 0.8.25:
  * viewer: add component selection support
  * buffer: add component id getter
  * buffer: fix multipart informations
- Changes for 0.8.24:
  * gv: fix multipart data accessor
  * gv: improve error handling of network API
* Sun Nov 27 2022 Matwey Kornilov <matwey.kornilov@gmail.com>
- Update license to LGPL-2.1
  https://github.com/AravisProject/aravis/commit/c20298b222012a63b3a73193e3849ba8980b2c07
* Thu Jul 21 2022 Matwey Kornilov <matwey.kornilov@gmail.com>
- Update to 0.8.22
  * camera: new network command for IP settings
  * camera: don't fail if TriggerSelector is not available
  * camera: make region setting work even without Offset features
  * camera: allow frame rate setting during acquisition on more devices
  * gstplugin: allow low frame rate with external triggers
  * genicam: list for forced legacy mode
  * genicam: access mode check policy
  * genicam: fix inifinite loop during availability check
  * u3v: use libusb device-left event for control lost detection
  * genicam: fix information loss
  * fake_camera: add TriggerSoftware support
  * build: appdata fix
  * build: disable documentation by default
  * tests: fix ChunkFloat test on big endian platform
  * introspection: fix user_data_destroy_func annotations
  * misc: memory leak and warning fixes
* Mon May  9 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.8.21
  * gigevision: performance improvement of standard socket method
  * usb3vision: prevent USB command mix up
  * usb3vision: fix PacketResend size field in extended ID mode
  * genicam: allow more Category child nodes
  * genicam: AccessMode fixes
  * genicam: fix pIsLocked when target is a Boolean node
  * doc: port to gi-docgen
* Mon Dec 13 2021 Matwey Kornilov <matwey.kornilov@gmail.com>
- Split arv-viewer to separate package: it requires GTK and graphical stack
  while other arv tools can be installed on head-less systems.
* Sat Sep 25 2021 Matwey Kornilov <matwey.kornilov@gmail.com>
- Update to version 0.8.18
* Tue Sep  7 2021 Matwey Kornilov <matwey.kornilov@gmail.com>
- Update to version 0.6.4
* Mon Jul  8 2019 Matwey Kornilov <matwey.kornilov@gmail.com>
- Fix Group:
- Drop unused %%postun
* Sat Jul  6 2019 Matwey V. Kornilov <matwey.kornilov@gmail.com>
- Update to version 0.6.3
* Mon Aug  8 2016 matwey.kornilov@gmail.com
- Update to version 0.4.0:
  * buffer: add a timestamp setter
  * interface: don't touch device list on open device
  * viewer: fix appdata file
* Sun Jun 19 2016 matwey.kornilov@gmail.com
- Version 0.3.8
  Based on huaren.zhong@gmail.com fedora aravis.spec
